/**
 * Copyright 2008 Peach Jean Solutions
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.xj4.parameterized;

import java.lang.annotation.Documented;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;
import java.lang.annotation.ElementType;
import java.lang.annotation.Inherited;

/**
 * Indicates that a test method requires a parameter set when run.  The method must still be annotated with
 * {@link org.junit.Test}.
 * Date: Feb 19, 2008
 * Time: 3:14:17 PM
 *
 * @author jbunting
 * @see org.xj4.XJ4Runner
 */

@Documented
@Retention(RetentionPolicy.RUNTIME)
@Target(ElementType.METHOD)
@Inherited
public @interface Parameterized {
  /**
   * The name of the parameter sets to use.  If more than one is specified, the "effective" parameter set will be
   * the cross product of all parameter sets specified.
   *
   * @return the name of the parameter set
   */
  public String value() default "";
}
