/**
 * Copyright 2008 Peach Jean Solutions
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.xj4.parameterized;

import org.apache.commons.lang.NullArgumentException;

/**
 * @author jbunting
 * @TODO Document Me!
 * Created by IntelliJ IDEA.
 * Date: Mar 3, 2008
 * Time: 8:30:13 AM
 */
public class SimpleMergeParameterSet extends AbstractCombinedParameterSet {

  public SimpleMergeParameterSet(ParameterSet... subSets) {
    this(null, subSets);
  }

  public SimpleMergeParameterSet(String[] labelArray, ParameterSet ... subSets) {
    this(null, labelArray, subSets);
  }
  
  public SimpleMergeParameterSet(String name, String[] labelArray, ParameterSet... subSets) {
    super(name, labelArray, subSets);
  }

  public void validate() {
    if(getSubDefinitions().length < 1) {
      throw new IllegalArgumentException("At least one sub definition must be specified!");
    }
    for(ParameterSet definition : getSubDefinitions()) {
      if(definition == null) {
        throw new NullArgumentException("Sub definitions cannot be null!");
      }
    }
    int seedLength = getSubDefinitions()[0].getNumIterations();
    for(int i = 1; i < getSubDefinitions().length; i++) {
      if(getSubDefinitions()[i].getNumIterations() != seedLength) {
        throw new IllegalArgumentException("All sub definitions must have the same number of iterations!");
      }
    }
  }

  public int getNumIterations() {
    return getSubDefinitions()[0].getNumIterations();
  }

  public int getIterationSize() {
    int size = 0;
    for(ParameterSet subSet : getSubDefinitions()) {
      size += subSet.getIterationSize();
    }
    return size;
  }

  protected String getLabelSeparator() {
    return "+";
  }

  protected int getSubDefinitionIteration(int iteration, int subDefinitionIndex) {
    return iteration;
  }
}
